# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.network_account_info import NetworkAccountInfo
from typing import Optional, Set
from typing_extensions import Self

class AccountInfo(BaseModel):
    """
    Account Information
    """ # noqa: E501
    account_id: StrictInt = Field(description="The Account Id", alias="accountId")
    dataset_id: Optional[StrictStr] = Field(default=None, description="The Dataset Id", alias="datasetId")
    dataset_uri: StrictStr = Field(description="The dataset URI", alias="datasetUri")
    features: Optional[Dict[str, StrictBool]] = Field(default=None, description="A list of features enabled or disabled for the account")
    google_search_console_site_url: Optional[StrictStr] = Field(default=None, description="Google Search Console Site URL", alias="googleSearchConsoleSiteUrl")
    include_exclude_default: Optional[StrictStr] = Field(default='include', description="The default setting for include/exclude URLs.", alias="includeExcludeDefault")
    key: Optional[StrictStr] = Field(default=None, description="The Key")
    language: Optional[StrictStr] = Field(default=None, description="The language code")
    networks: List[NetworkAccountInfo] = Field(description="A list of connected Account Information")
    ng_dataset_id: Optional[StrictStr] = Field(default=None, alias="ngDatasetId")
    subscription_id: StrictInt = Field(description="The Subscription Id", alias="subscriptionId")
    url: Optional[StrictStr] = Field(default=None, description="The website URL")
    wp_admin: Optional[StrictStr] = Field(default=None, description="If WordPress, the WP-ADMIN URL", alias="wpAdmin")
    wp_json: Optional[StrictStr] = Field(default=None, description="If WordPress, the WP-JSON end-point", alias="wpJson")
    __properties: ClassVar[List[str]] = ["accountId", "datasetId", "datasetUri", "features", "googleSearchConsoleSiteUrl", "includeExcludeDefault", "key", "language", "networks", "ngDatasetId", "subscriptionId", "url", "wpAdmin", "wpJson"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of AccountInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "account_id",
            "dataset_id",
            "dataset_uri",
            "features",
            "google_search_console_site_url",
            "include_exclude_default",
            "key",
            "language",
            "networks",
            "subscription_id",
            "url",
            "wp_admin",
            "wp_json",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in networks (list)
        _items = []
        if self.networks:
            for _item in self.networks:
                if _item:
                    _items.append(_item.to_dict())
            _dict['networks'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of AccountInfo from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "accountId": obj.get("accountId"),
            "datasetId": obj.get("datasetId"),
            "datasetUri": obj.get("datasetUri"),
            "features": obj.get("features"),
            "googleSearchConsoleSiteUrl": obj.get("googleSearchConsoleSiteUrl"),
            "includeExcludeDefault": obj.get("includeExcludeDefault") if obj.get("includeExcludeDefault") is not None else 'include',
            "key": obj.get("key"),
            "language": obj.get("language"),
            "networks": [NetworkAccountInfo.from_dict(_item) for _item in obj["networks"]] if obj.get("networks") is not None else None,
            "ngDatasetId": obj.get("ngDatasetId"),
            "subscriptionId": obj.get("subscriptionId"),
            "url": obj.get("url"),
            "wpAdmin": obj.get("wpAdmin"),
            "wpJson": obj.get("wpJson")
        })
        return _obj





# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class MerchantView(BaseModel):
    """
    An array of objects.
    """ # noqa: E501
    access_token: StrictStr = Field(description="The Google merchant access token")
    account_id: Optional[StrictInt] = Field(default=None, description="The account id")
    automatic_synchronization: Optional[StrictBool] = Field(default=None, description="Whether the Merchant data will be synchronized automatically")
    created_at: Optional[datetime] = Field(default=None, description="The create date-time")
    custom_seller: Optional[StrictStr] = Field(default=None, description="Custom seller entity - if applicable.")
    dataset_domain: Optional[StrictStr] = Field(default=None, description="The custom domain (for example data.example.org)")
    dataset_name: Optional[StrictStr] = Field(default=None, description="The dataset path (for example /data)")
    default_products_filter_action: StrictStr = Field(description="Default Products filter action to apply during sync process.")
    deleted: StrictBool = Field(description="True if the merchant has been deleted")
    deleted_at: Optional[datetime] = Field(default=None, description="The delete date-time")
    google_merchant_id: StrictInt = Field(description="The Google Merchant id")
    id: Optional[StrictInt] = Field(default=None, description="The unique id")
    ignore_brand: Optional[StrictBool] = Field(default=None, description="Whether to ignore the `brand` property during validation")
    ignore_image: Optional[StrictBool] = Field(default=None, description="Whether to ignore the `image` property during validation")
    modified_at: Optional[datetime] = Field(default=None, description="The last modified date-time")
    publisher_name: StrictStr = Field(description="The publisher name (shows in schema publisher)")
    refresh_token: StrictStr = Field(description="The Google merchant refresh token")
    sid: Optional[StrictStr] = None
    sync_has_errors: Optional[StrictBool] = None
    sync_id: Optional[StrictInt] = None
    sync_products_created: Optional[StrictInt] = None
    sync_products_deleted: Optional[StrictInt] = None
    sync_products_errored: Optional[StrictInt] = None
    sync_products_skipped: Optional[StrictInt] = None
    sync_products_total: Optional[StrictInt] = None
    sync_products_unchanged: Optional[StrictInt] = None
    sync_products_updated: Optional[StrictInt] = None
    sync_started_at: Optional[datetime] = Field(default=None, description="The started date-time.")
    sync_stopped_at: Optional[datetime] = Field(default=None, description="The stopped date-time.")
    url: Optional[StrictStr] = Field(default=None, description="The website URL")
    url_strategy: Optional[Annotated[str, Field(min_length=0, strict=True, max_length=50)]] = Field(default='canonicalLinkAndLink', description="Which strategy to use to write the url schema.")
    writer_service: Optional[StrictStr] = Field(default=None, description="How to write the merchant data to the graph, if unsure, do not set anything (by default `wordpressMerchantWriter`).")
    __properties: ClassVar[List[str]] = ["access_token", "account_id", "automatic_synchronization", "created_at", "custom_seller", "dataset_domain", "dataset_name", "default_products_filter_action", "deleted", "deleted_at", "google_merchant_id", "id", "ignore_brand", "ignore_image", "modified_at", "publisher_name", "refresh_token", "sid", "sync_has_errors", "sync_id", "sync_products_created", "sync_products_deleted", "sync_products_errored", "sync_products_skipped", "sync_products_total", "sync_products_unchanged", "sync_products_updated", "sync_started_at", "sync_stopped_at", "url", "url_strategy", "writer_service"]

    @field_validator('default_products_filter_action')
    def default_products_filter_action_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['PROCESS', 'IGNORE']):
            raise ValueError("must be one of enum values ('PROCESS', 'IGNORE')")
        return value

    @field_validator('url_strategy')
    def url_strategy_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        if value not in set(['canonicalLinkAndLink', 'canonicalLinkOtherwiseLink']):
            raise ValueError("must be one of enum values ('canonicalLinkAndLink', 'canonicalLinkOtherwiseLink')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of MerchantView from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        """
        excluded_fields: Set[str] = set([
            "account_id",
            "created_at",
            "deleted_at",
            "id",
            "modified_at",
            "sync_started_at",
            "sync_stopped_at",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of MerchantView from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "access_token": obj.get("access_token"),
            "account_id": obj.get("account_id"),
            "automatic_synchronization": obj.get("automatic_synchronization"),
            "created_at": obj.get("created_at"),
            "custom_seller": obj.get("custom_seller"),
            "dataset_domain": obj.get("dataset_domain"),
            "dataset_name": obj.get("dataset_name"),
            "default_products_filter_action": obj.get("default_products_filter_action") if obj.get("default_products_filter_action") is not None else 'PROCESS',
            "deleted": obj.get("deleted") if obj.get("deleted") is not None else False,
            "deleted_at": obj.get("deleted_at"),
            "google_merchant_id": obj.get("google_merchant_id"),
            "id": obj.get("id"),
            "ignore_brand": obj.get("ignore_brand"),
            "ignore_image": obj.get("ignore_image"),
            "modified_at": obj.get("modified_at"),
            "publisher_name": obj.get("publisher_name"),
            "refresh_token": obj.get("refresh_token"),
            "sid": obj.get("sid"),
            "sync_has_errors": obj.get("sync_has_errors"),
            "sync_id": obj.get("sync_id"),
            "sync_products_created": obj.get("sync_products_created"),
            "sync_products_deleted": obj.get("sync_products_deleted"),
            "sync_products_errored": obj.get("sync_products_errored"),
            "sync_products_skipped": obj.get("sync_products_skipped"),
            "sync_products_total": obj.get("sync_products_total"),
            "sync_products_unchanged": obj.get("sync_products_unchanged"),
            "sync_products_updated": obj.get("sync_products_updated"),
            "sync_started_at": obj.get("sync_started_at"),
            "sync_stopped_at": obj.get("sync_stopped_at"),
            "url": obj.get("url"),
            "url_strategy": obj.get("url_strategy") if obj.get("url_strategy") is not None else 'canonicalLinkAndLink',
            "writer_service": obj.get("writer_service")
        })
        return _obj





# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.level_enum import LevelEnum
from wordlift_client.models.project_type import ProjectType
from wordlift_client.models.scope import Scope
from wordlift_client.models.validation_fix import ValidationFix
from wordlift_client.models.what_operand_lhs import WhatOperandLhs
from wordlift_client.models.what_operator import WhatOperator
from wordlift_client.models.when_operator import WhenOperator
from typing import Optional, Set
from typing_extensions import Self

class RuleRequest(BaseModel):
    """
    RuleRequest
    """ # noqa: E501
    description: Optional[StrictStr] = Field(default=None, description="Description for the rule")
    fixes: Optional[List[ValidationFix]] = Field(default=None, description="The list of fixes to apply when the rule validation fails.")
    is_enabled: Optional[StrictBool] = None
    level: LevelEnum
    name: StrictStr = Field(description="The rule name.")
    project_id: Optional[StrictInt] = Field(default=None, description="The project id, if applicable.")
    project_type: Optional[ProjectType] = None
    scope: Scope
    type: StrictStr = Field(description="The rule type, one of `field`, `word` or `code`. By default `field`.")
    what_operand_lhs: WhatOperandLhs
    what_operand_rhs: StrictStr = Field(description="The right hand side operand for what condition.")
    what_operator: WhatOperator
    when_operand_lhs: StrictStr = Field(description="The left hand side  operand for when condition.")
    when_operand_rhs: StrictStr = Field(description="The right hand side operand for when condition.")
    when_operator: WhenOperator
    __properties: ClassVar[List[str]] = ["description", "fixes", "is_enabled", "level", "name", "project_id", "project_type", "scope", "type", "what_operand_lhs", "what_operand_rhs", "what_operator", "when_operand_lhs", "when_operand_rhs", "when_operator"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RuleRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in fixes (list)
        _items = []
        if self.fixes:
            for _item in self.fixes:
                if _item:
                    _items.append(_item.to_dict())
            _dict['fixes'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RuleRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "description": obj.get("description"),
            "fixes": [ValidationFix.from_dict(_item) for _item in obj["fixes"]] if obj.get("fixes") is not None else None,
            "is_enabled": obj.get("is_enabled"),
            "level": obj.get("level"),
            "name": obj.get("name"),
            "project_id": obj.get("project_id"),
            "project_type": obj.get("project_type"),
            "scope": obj.get("scope"),
            "type": obj.get("type"),
            "what_operand_lhs": obj.get("what_operand_lhs"),
            "what_operand_rhs": obj.get("what_operand_rhs"),
            "what_operator": obj.get("what_operator"),
            "when_operand_lhs": obj.get("when_operand_lhs"),
            "when_operand_rhs": obj.get("when_operand_rhs"),
            "when_operator": obj.get("when_operator")
        })
        return _obj





# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.models.response import Response

class TestResponse(unittest.TestCase):
    """Response unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> Response:
        """Test Response
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `Response`
        """
        model = Response()
        if include_optional:
            return Response(
                entities = {
                    'key' : wordlift_client.models.entity.Entity(
                        entity_id = '', 
                        confidence = 1.337, 
                        main_type = '', 
                        types = [
                            ''
                            ], 
                        label = '', 
                        description = '', 
                        images = [
                            ''
                            ], 
                        same_as = [
                            ''
                            ], 
                        properties = wordlift_client.models.properties.Properties(
                            latitude = 1.337, 
                            longitude = 1.337, ), 
                        synonyms = [
                            ''
                            ], )
                    },
                annotations = {
                    'key' : wordlift_client.models.annotation.Annotation(
                        annotation_id = '', 
                        start = 56, 
                        end = 56, 
                        text = '', 
                        entity_matches = [
                            wordlift_client.models.entity_match.EntityMatch(
                                confidence = 1.337, 
                                entity_id = '', )
                            ], )
                    },
                images = [
                    wordlift_client.models.image.Image(
                        label = '', 
                        url = '', )
                    ],
                languages = [
                    ''
                    ],
                topics = [
                    wordlift_client.models.topic.Topic(
                        label = '', 
                        description = '', 
                        uri = '', 
                        confidence = 1.337, 
                        images = [
                            ''
                            ], 
                        same_as = [
                            ''
                            ], )
                    ],
                content = ''
            )
        else:
            return Response(
        )
        """

    def testResponse(self):
        """Test Response"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    GraphQL support

    GraphQL endpoint to query Knowledge Graphs

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from wordlift_client.models.annotation import Annotation
from wordlift_client.models.entity1 import Entity1
from wordlift_client.models.image import Image
from wordlift_client.models.topic import Topic
from typing import Optional, Set
from typing_extensions import Self

class Response(BaseModel):
    """
    Response
    """ # noqa: E501
    entities: Optional[Dict[str, Entity1]] = Field(default=None, description="A map of entity URI to the respective entity.")
    annotations: Optional[Dict[str, Annotation]] = Field(default=None, description="A map of annotation id to the respective annotation.")
    images: Optional[List[Image]] = Field(default=None, description="A list of images.")
    languages: Optional[List[StrictStr]] = Field(default=None, description="A list of languages.")
    topics: Optional[List[Topic]] = Field(default=None, description="A list of topics.")
    content: Optional[StrictStr] = Field(default=None, description="The text supplied for analysis.")
    __properties: ClassVar[List[str]] = ["entities", "annotations", "images", "languages", "topics", "content"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Response from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in entities (dict)
        _field_dict = {}
        if self.entities:
            for _key in self.entities:
                if self.entities[_key]:
                    _field_dict[_key] = self.entities[_key].to_dict()
            _dict['entities'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each value in annotations (dict)
        _field_dict = {}
        if self.annotations:
            for _key in self.annotations:
                if self.annotations[_key]:
                    _field_dict[_key] = self.annotations[_key].to_dict()
            _dict['annotations'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each item in images (list)
        _items = []
        if self.images:
            for _item in self.images:
                if _item:
                    _items.append(_item.to_dict())
            _dict['images'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in topics (list)
        _items = []
        if self.topics:
            for _item in self.topics:
                if _item:
                    _items.append(_item.to_dict())
            _dict['topics'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Response from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "entities": dict(
                (_k, Entity1.from_dict(_v))
                for _k, _v in obj["entities"].items()
            )
            if obj.get("entities") is not None
            else None,
            "annotations": dict(
                (_k, Annotation.from_dict(_v))
                for _k, _v in obj["annotations"].items()
            )
            if obj.get("annotations") is not None
            else None,
            "images": [Image.from_dict(_item) for _item in obj["images"]] if obj.get("images") is not None else None,
            "languages": obj.get("languages"),
            "topics": [Topic.from_dict(_item) for _item in obj["topics"]] if obj.get("topics") is not None else None,
            "content": obj.get("content")
        })
        return _obj


